@@ -6,7 +6,7 @@ from rest_framework.reverse import reverse
 from rest_framework import serializers, relations
 
 from pulp_ansible.app import models
-from pulpcore.plugin.models import ContentArtifact
+from pulpcore.plugin.models import ContentArtifact, RepositoryVersion
 
 
 class CollectionSerializer(serializers.ModelSerializer):
@@ -218,10 +218,10 @@ class CollectionVersionSerializer(UnpaginatedCollectionVersionSerializer):
     A serializer for a CollectionVersion.
     """
 
-    manifest = serializers.DictField(
+    manifest = serializers.JSONField(
         help_text="A JSON field holding MANIFEST.json data.", read_only=True
     )
-    files = serializers.DictField(help_text="A JSON field holding FILES.json data.", read_only=True)
+    files = serializers.JSONField(help_text="A JSON field holding FILES.json data.", read_only=True)
 
     class Meta:
         model = models.CollectionVersion
@@ -248,4 +248,4 @@ class RepoMetadataSerializer(serializers.ModelSerializer):
 
     class Meta:
         fields = ("published",)
-        model = models.RepositoryVersion
+        model = RepositoryVersion
