@@ -12,7 +12,6 @@ from aiohttp.client_exceptions import ClientResponseError
 from async_lru import alru_cache
 from django.conf import settings
 from django.db import transaction
-from django.db.models import Q
 from django.urls import reverse
 from django.utils.dateparse import parse_datetime
 from galaxy_importer.collection import import_collection as process_collection
@@ -28,6 +27,7 @@ from pulpcore.plugin.models import (
     ProgressReport,
     PulpTemporaryFile,
     Remote,
+    RepositoryContent,
     Task,
 )
 from pulpcore.plugin.stages import (
@@ -126,10 +126,6 @@ def sync(remote_pk, repository_pk, mirror, optimize):
         raise ValueError(_("A CollectionRemote must have a 'url' specified to synchronize."))
 
     first_stage = CollectionSyncFirstStage(remote, repository, optimize)
-    if first_stage.should_sync is False:
-        log.debug(_("no-op: remote wasn't updated since last sync."))
-        return
-
     d_version = AnsibleDeclarativeVersion(first_stage, repository, mirror=mirror)
     repo_version = d_version.create()
 
@@ -140,21 +136,10 @@ def sync(remote_pk, repository_pk, mirror, optimize):
         repository.last_synced_metadata_time = first_stage.last_synced_metadata_time
         repository.save()
 
-    to_deprecate = []
-    if first_stage.deprecations:
-        collections_deprecate_true_qs = Collection.objects.filter(first_stage.deprecations)
-        for collection in collections_deprecate_true_qs:
-            to_deprecate.append(
-                AnsibleCollectionDeprecated(repository_version=repo_version, collection=collection)
-            )
-
-        AnsibleCollectionDeprecated.objects.bulk_create(to_deprecate, ignore_conflicts=True)
-
-    non_deprecated_qs = Collection.objects.exclude(first_stage.deprecations)
-    AnsibleCollectionDeprecated.objects.filter(
-        repository_version=repo_version,
-        collection__pk__in=non_deprecated_qs,
-    ).delete()
+    deprecated = AnsibleCollectionDeprecated.objects.filter(pk__in=repo_version.content)
+    RepositoryContent.objects.filter(repository=repository, content__in=deprecated).exclude(
+        version_added=repo_version
+    ).all().update(version_removed=repo_version)
 
 
 def import_collection(
@@ -377,8 +362,8 @@ class CollectionSyncFirstStage(Stage):
         super().__init__()
         self.remote = remote
         self.repository = repository
+        self.optimize = optimize
         self.collection_info = parse_collections_requirements_file(remote.requirements_file)
-        self.deprecations = Q()
         self.add_dependents = self.collection_info and self.remote.sync_dependencies
         self.already_synced = set()
         self._unpaginated_collection_metadata = None
@@ -388,11 +373,6 @@ class CollectionSyncFirstStage(Stage):
         # Interpret download policy
         self.deferred_download = self.remote.policy != Remote.IMMEDIATE
 
-        # Check if we should sync
-        self.should_sync = not optimize or asyncio.get_event_loop().run_until_complete(
-            self._should_we_sync()
-        )
-
     @alru_cache(maxsize=128)
     async def _get_root_api(self, root):
         """
@@ -497,7 +477,7 @@ class CollectionSyncFirstStage(Stage):
             d_artifacts=[d_artifact],
             extra_data=extra_data,
         )
-        self.parsing_metadata_progress_bar.increment()
+        await self.parsing_metadata_progress_bar.aincrement()
         await self.put(d_content)
 
     def _collection_versions_list_downloader(
@@ -535,7 +515,10 @@ class CollectionSyncFirstStage(Stage):
                     version_num = collection_version["version"]
                     collection_version_detail_url = f"{collection_url}/versions/{version_num}/"
                     if collection_metadata["deprecated"]:
-                        self.deprecations |= Q(namespace=namespace, name=name)
+                        d_content = DeclarativeContent(
+                            content=AnsibleCollectionDeprecated(namespace=namespace, name=name),
+                        )
+                        await self.put(d_content)
                     tasks.append(
                         loop.create_task(
                             self._fetch_collection_version_metadata(
@@ -556,7 +539,10 @@ class CollectionSyncFirstStage(Stage):
         loop = asyncio.get_event_loop()
 
         if self._unpaginated_collection_metadata[namespace][name]["deprecated"]:
-            self.deprecations |= Q(namespace=namespace, name=name)
+            d_content = DeclarativeContent(
+                content=AnsibleCollectionDeprecated(namespace=namespace, name=name),
+            )
+            await self.put(d_content)
 
         all_versions_of_collection = self._unpaginated_collection_version_metadata[namespace][name]
 
@@ -652,9 +638,12 @@ class CollectionSyncFirstStage(Stage):
         for collection_namespace_dict in self._unpaginated_collection_metadata.values():
             for collection in collection_namespace_dict.values():
                 if collection["deprecated"]:
-                    self.deprecations |= Q(
-                        namespace=collection["namespace"], name=collection["name"]
+                    d_content = DeclarativeContent(
+                        content=AnsibleCollectionDeprecated(
+                            namespace=collection["namespace"], name=collection["name"]
+                        ),
                     )
+                    await self.put(d_content)
 
         for collections_in_namespace in self._unpaginated_collection_version_metadata.values():
             for collection_versions in collections_in_namespace.values():
@@ -763,11 +752,17 @@ class CollectionSyncFirstStage(Stage):
         """
         Build and emit `DeclarativeContent` from the ansible metadata.
         """
+        if self.optimize:
+            should_we_sync = await self._should_we_sync()
+            if should_we_sync is False:
+                log.debug(_("no-op: remote wasn't updated since last sync."))
+                return
+
         tasks = []
         loop = asyncio.get_event_loop()
 
         msg = _("Parsing CollectionVersion Metadata")
-        with ProgressReport(message=msg, code="sync.parsing.metadata") as pb:
+        async with ProgressReport(message=msg, code="sync.parsing.metadata") as pb:
             self.parsing_metadata_progress_bar = pb
             await self._download_unpaginated_metadata()
 
@@ -833,7 +828,7 @@ class CollectionContentSaver(ContentSaver):
         super().__init__(*args, **kwargs)
         self.repository_version = repository_version
 
-    async def _pre_save(self, batch):
+    def _pre_save(self, batch):
         """
         Save a batch of Collection objects.
 
@@ -855,7 +850,7 @@ class CollectionContentSaver(ContentSaver):
 
             d_content.content.collection = collection
 
-    async def _post_save(self, batch):
+    def _post_save(self, batch):
         """
         Save a batch of CollectionVersion, Tag objects.
 
