@@ -31,6 +31,7 @@ from pulpcore.plugin.viewsets import (
 )
 from pulp_ansible.app.galaxy.mixins import UploadGalaxyCollectionMixin
 from .models import (
+    AnsibleCollectionDeprecated,
     AnsibleDistribution,
     RoleRemote,
     AnsibleRepository,
@@ -204,6 +205,16 @@ class CollectionVersionViewSet(SingleArtifactContentUploadViewSet, UploadGalaxyC
         return OperationPostponedResponse(async_result, request)
 
 
+class CollectionDeprecatedViewSet(ContentViewSet):
+    """
+    ViewSet for AnsibleCollectionDeprecated.
+    """
+
+    endpoint_name = "collection_deprecations"
+    queryset = AnsibleCollectionDeprecated.objects.all()
+    serializer_class = CollectionSerializer
+
+
 class RoleRemoteViewSet(RemoteViewSet):
     """
     ViewSet for Role Remotes.
