@@ -1,9 +1,7 @@
 """Tests related to sync ansible plugin collection content type."""
-import unittest
 from tempfile import NamedTemporaryFile
-
 from pulp_smash import api, config
-from pulp_smash.pulp3.bindings import delete_orphans, monitor_task
+from pulp_smash.pulp3.bindings import PulpTestCase, delete_orphans, monitor_task
 from pulp_smash.pulp3.utils import gen_repo, sync
 from pulp_smash.utils import http_get
 
@@ -22,7 +20,7 @@ from pulp_ansible.tests.functional.utils import gen_ansible_client, gen_ansible_
 from pulp_ansible.tests.functional.utils import set_up_module as setUpModule  # noqa:F401
 
 
-class ListContentVersionsCase(unittest.TestCase):
+class ListContentVersionsCase(PulpTestCase):
     """Test listing CollectionVersions."""
 
     @classmethod
@@ -74,7 +72,7 @@ class ListContentVersionsCase(unittest.TestCase):
         self.assertEqual(len(collections), 0, collections)
 
 
-class ContentUnitTestCase(unittest.TestCase):
+class ContentUnitTestCase(PulpTestCase):
     """CRUD content unit.
 
     This test targets the following issues:
@@ -96,7 +94,7 @@ class ContentUnitTestCase(unittest.TestCase):
         """Clean class-wide variable."""
         delete_orphans()
 
-    def upload_collection(self, namespace="pulp", name="squeezer", version="0.0.9"):
+    def upload_collection(self, namespace="pulp", name="pulp_installer", version="3.14.0"):
         """Upload collection."""
         url = f"https://galaxy.ansible.com/download/{namespace}-{name}-{version}.tar.gz"
         collection_content = http_get(url)
@@ -108,7 +106,7 @@ class ContentUnitTestCase(unittest.TestCase):
 
     def test_01_create_content_unit(self):
         """Create content unit."""
-        attrs = dict(namespace="pulp", name="squeezer", version="0.0.9")
+        attrs = dict(namespace="pulp", name="pulp_installer", version="3.14.0")
         response = self.upload_collection(**attrs)
         created_resources = monitor_task(response.task).created_resources
         content_unit = self.cv_content_api.read(created_resources[0])
@@ -174,7 +172,7 @@ class ContentUnitTestCase(unittest.TestCase):
     @skip_if(bool, "content_unit", False)
     def test_05_duplicate_raise_error(self):
         """Attempt to create duplicate collection."""
-        attrs = dict(namespace="pulp", name="squeezer", version="0.0.9")
+        attrs = dict(namespace="pulp", name="pulp_installer", version="3.14.0")
         with self.assertRaises(ApiException) as ctx:
             self.upload_collection(**attrs)
         self.assertIn(
