@@ -10,7 +10,7 @@ from pulpcore.client.pulp_ansible import (
     RepositoriesAnsibleApi,
     RemotesCollectionApi,
 )
-from pulp_smash.pulp3.bindings import PulpTaskError
+from pulp_smash.pulp3.bindings import PulpTaskError, PulpTestCase
 
 from pulp_ansible.tests.functional.utils import (
     gen_ansible_client,
@@ -136,35 +136,6 @@ class SyncCollectionsFromPulpServerTestCase(TestCaseUsingBindings, SyncHelpersMi
         messages = [r.message for r in task.progress_reports]
         self.assertIn(msg, str(messages))
 
-    def test_noop_resync_with_mirror_from_pulp(self):
-        """Test whether no-op sync with mirror=True doesn't remove repository content."""
-        second_body = gen_ansible_remote(
-            url=self.distribution.client_url,
-            requirements_file=self.requirements_file,
-            sync_dependencies=False,
-        )
-        second_remote = self.remote_collection_api.create(second_body)
-        self.addCleanup(self.remote_collection_api.delete, second_remote.pulp_href)
-
-        second_repo = self._create_repo_and_sync_with_remote(second_remote)
-
-        second_content = self.cv_api.list(repository_version=f"{second_repo.pulp_href}versions/1/")
-        self.assertGreaterEqual(len(second_content.results), 1)
-
-        # Resync
-        repository_sync_data = AnsibleRepositorySyncURL(
-            remote=second_remote.pulp_href, optimize=True, mirror=True
-        )
-        sync_response = self.repo_api.sync(second_repo.pulp_href, repository_sync_data)
-        monitor_task(sync_response.task)
-        second_repo = self.repo_api.read(second_repo.pulp_href)
-        self.assertEqual(int(second_repo.latest_version_href[-2]), 1)
-        task = tasks.read(sync_response.task)
-
-        msg = "no-op: {url} did not change since last sync".format(url=second_remote.url)
-        messages = [r.message for r in task.progress_reports]
-        self.assertIn(msg, str(messages))
-
     def test_update_requirements_file(self):
         """Test requirements_file update."""
         body = gen_ansible_remote(
@@ -191,7 +162,7 @@ class SyncCollectionsFromPulpServerTestCase(TestCaseUsingBindings, SyncHelpersMi
     "AUTOMATION_HUB_TOKEN_AUTH" in os.environ,
     "'AUTOMATION_HUB_TOKEN_AUTH' env var is not defined",
 )
-class AutomationHubV3SyncCase(unittest.TestCase, SyncHelpersMixin):
+class AutomationHubV3SyncCase(PulpTestCase, SyncHelpersMixin):
     """Test syncing from Pulp to Pulp."""
 
     @classmethod
@@ -230,7 +201,7 @@ class AutomationHubV3SyncCase(unittest.TestCase, SyncHelpersMixin):
     "QA_AUTOMATION_HUB_TOKEN_AUTH" in os.environ,
     "'QA_AUTOMATION_HUB_TOKEN_AUTH' env var is not defined",
 )
-class AutomationHubCIV3SyncCase(unittest.TestCase, SyncHelpersMixin):
+class AutomationHubCIV3SyncCase(PulpTestCase, SyncHelpersMixin):
     """Test syncing from Pulp to Pulp."""
 
     @classmethod
